# YASARA MOVIE
# TOPIC:    6. Multimedia
# TITLE:    6.2. The protein structure group at the CMBI
# REQUIRES: Dynamics 8.11.1
# AUTHOR:   Elmar Krieger
# LICENSE:  GNU GPL, Grass texture by Rune S. Johansen
# DESCRIPTION: An introduction to the 'Vriend Group' at the CMBI, can be easily adapted to introduce your own research group

# Change working directory to the place of this macro
# (so that we don't have to specify paths when loading stuff).
CD (MacroDir)

if Help
  # If we are showing a help movie, wait for clicks on the ContinueButton
  Button='ContinueButton'
else
  # Otherwise it's a presentation. Wait for a clicks on the left mouse button, go fullscreen
  Button='LeftButton'
  Menu Off

# Left handed coordinate system
Clear
CoordSys Left
Projection perspective
Console Off
HUD Off
HideMessage
UserInput Off
# Basic graphics styles
StickRadius 50
BallStickRadius 50,50
ColorBG 000060,White
ColorBonds Grey
Fog 60
LightSource 45,45,Ambience=0,Shadow=40
AtomSize 100

# Basic simulation parameters
Boundary Wall
Longrange None
ForceField AMBER99
Temp 0K

# Load background sky+grass and animate a bit
LoadPNG sky
ShowImage sky,0,0,1024,768,Alpha=100,Priority=0
AutoMoveImage sky,256,256,512,384,Alpha=100,Steps=2000,Cycle=Yes
LoadPNG grass

# Some variables
grasslen=400
#Go Scene2

#
# Scene 1 - Vriend group appears
#
Scene1:
DelAll
LightSource Shadow=0
MakeImageObj grass,grass,width=(grasslen),height=(grasslen)
PosObj grass,Z=350
# Add 150 single amino acids as 'bushes' on the grass
Style Ball,Stick
reslist='Arg','Gln','Met'
for i=1 to 150
  residue=reslist(i%3+1)
  obj=BuildRes (residue)
  # GET THE Z-COORDINATE
  x,y,z=PosAtom CA Obj (obj)
  MoveAtom Obj (obj),Z=(-z)
  PosObj (obj),X=((rnd 1-0.5)*grasslen),Y=((rnd 1-0.5)*grasslen),Z=349
  RotateObj (obj),X=180
  ColorObj (obj),(200+rnd 80)
  if obj==3
    JoinObj 3,2
StickAtom SideChain

# Load Yami
LoadYOb yami
PosObj Yami,Z=327
OriObj Yami,Alpha=90,Beta=180,Gamma=-90
if Help
  ShowMessage "This movie needs to be played with the song 'To be free' by Mike Oldfield as background music"
Wait (Button)
HideMessage

# Zoom in on Yami
#Wait 200
AutoRotate Z=1
AutoPos Z=80,Steps=405,Wait=No
Wait 200
Wait 205
AutoRotate Z=0
AutoRotate X=1
AutoMove Y=-0.3
Wait 90
AutoRotate X=0
AutoMove Y=0
if Help
  ShowMessage "You find yourself alone sometimes, without a home, no protection..."
# Add shadow
for i=1 to 40
  LightSource Shadow=(i)
  Wait 1  
# Let Yami jump along
yax,yay,yaz=PosObj Yami
ts=0.7
for i=0 to 840
  if i<210 or i>630
    Move X=0.643,Z=0.643
    angle=0
  else
    Move X=-0.643,Z=-0.643
    angle=180
  if i>155 and i<245
    angle=(i-155)*2
  if i>585 and i<675
    angle=(675-i)*2
  step=i%70
  height=sin (180.*step/70)*18
  # Rotate Yami's antennas
  Dihedral N Res Lys,CA Res Lys,CB Res Lys,CG Res Lys Obj Yami,bound=Yes,set=((5.14*step)-180)
  # Place Yami
  PosObj Yami,(yax),(yay+height),(yaz)
  OriObj Yami,0,90,0
  RotateObj Yami,Z=(sin (360.*step/70)*30)
  RotateObj Yami,Y=(angle-45)
  # Update text
  if Help
    if i==300
      ShowMessage "..you don't know which way to go, you are lost, no direction."
    if i==600
      ShowMessage "Then suddenly out of the blue, some kind of magic comes to you."
  Wait 1

# Let Yami look back
AutoRotateObj Yami,Y=5
Wait 27
AutoRotateObj Yami,Y=0

# Vriend group logo
MakeTextObj Vriend,Width=500,Height=36
Font Arial,Height=100%,Color=ffc050,Spacing=2,Depth=40,DepthCol=c06020
PosText 50%,0%,justify=Center
Print "VRIEND=GROUP>"

# Let the Vriend group appear
PosObj Vriend,Y=-180,Z=950
RotateObj Vriend,X=-90
AutoRotateObj Vriend,X=-5
AutoPosObj Vriend,Y=-11.5,Steps=60,Wait=No
Wait 24
AutoRotateObj Yami,Y=5
Wait 36
AutoRotateObj Yami,Y=0

# Let Yami run for his life
if Help
  ShowMessage "You don't know how, you don't know why, but some day you're gonna take off and fly.."
for i=0 to 560
  Move Z=0.74
  step=i%70
  # Rotate Yami's antennas
  Dihedral N Res Lys,CA Res Lys,CB Res Lys,CG Res Lys Obj Yami,bound=Yes,set=(5*step-180)
  # Place Yami
  if i<420
    height=sin (180.*step/70)*18
    PosObj Yami,(yax),(yay+height),(yaz)
    OriObj Yami,0,0,0
    RotateObj Yami,X=(sin (360.*step/70)*-30)
    height=sin (180.*i/420)*30
  else
    MoveObj Yami,Y=-(0.1*(i-(600*ts)))
    height=sin (-180.*(i-220)/200)*100
  # Place Vriend
  PosObj Vriend,Y=(-11.5+height),Z=(950-(1100*i/560))
  if i==420 and Help
    ShowMessage "Fly, fly, fly...   And my wish would be..."
  if i==280
    # Take snapshot here, Eliza!
    pass
  Wait 1
SwitchObj Yami Vriend,Off
AutoMove Y=3
Wait 100
AutoMove Y=0
DelObj 2
#SaveSce scene2

#
# Scene 2 - The circle
#
Scene2:
LoadSce scene2
LightSource Shadow=40
SwitchObj Yami Vriend,on
y=-900
z=90
PosObj Grass,X=0,Y=(y),Z=(z)
OriObj Grass,90,0,0
PosObj Yami,X=0,Y=55,Z=(z)
OriObj Yami,90,0,0
PosObj Vriend,X=0,Y=500,Z=(z)
OriObj Vriend,0,0,-90
AutoRotateObj Vriend,X=0

# Draw the circle of group members
gmlist='Simon', 'Jeroen','Erwin', 'Remko', 'Sander','Chris', 'Robbie','Elmar', 'Martin','Marc'
gmcola='ff8080','ffc080','ffff80','c0ff80','80ff80','80ffc0','80ffff','80c0ff','8080ff','c080ff'
gmcolb='804040','806040','808040','608040','408040','408060','408080','406080','404080','604080'

Jeroen="No Message yet!"
Marc  ="Marc is comparing sick people to find new genes."
Robbie="Robbie Joosten is trying to improve rotamers in other people's xray structures before he attempts to do his own xray experiments."
Simon ="Simon Folkertsma is destroying a nuclear receptor, hoping to learn something about it."
Remko ="Remko is developing perpetuum mobile programs."
Chris ="Chris is telling NMR spectroscopists about the difference between good and bad protein structure models and their uncertainty."
Elmar ="Elmar Krieger is working on protein structure prediction, with an emphasis on new methods to circumvent Murphy's Law."
Erwin ="Erwin Datema is building a flexible plant EST database during his thesis at the CMBI."
Sander="Sander thinks that biomolecular NMR structures are as nice as the QUEEN in her most beautiful DRESS."
Martin="Martin Oti will spend a year comparing flies with sick people at the CMBI."

members=count gmlist
alpha=360./members
radius=180.
for i=1 to members
  MakeTextObj Member(i),Width=200,Height=26
  Font Arial,Height=100%,Color=(gmcola(i)),Spacing=2,Depth=30,DepthCol=(gmcolb(i))
  PosText 50%,0%,justify=Center
  Print (gmlist(i))
  PosObj Member(i),X=(cos (alpha*i)*radius),Y=(y+13),Z=(sin (alpha*i)*radius+z)
  RotateObj Member(i),Y=(270-alpha*i)
  AutoPosObj Member(i),Y=-9,Steps=360,Wait=No

# Let Yami fall down
if Help
  ShowMessage "To be free, to be wise, and to be - just like a child."
AutoPosObj Grass,Y=-22,Steps=360,Wait=No
AutoRotateObj Yami,X=4
AutoPosObj Yami,Y=-13,Steps=360
AutoRotateObj Yami,X=0

# Let the earth shake
for i=5 to 1 step -1
  Move Y=(-i)
  Wait 2
  Move Y=(i)
  Wait 2

# Let Yami roll to the right
AutoPosObj Yami,X=28,Steps=90,Wait=No
AutoRotateObj Yami,Z=-4
AutoPosObj Vriend,Y=212,Steps=90
AutoRotateObj Yami,Z=0

# Let the earth shake again stronger
for i=10 to 1 step -1
  Move Y=(-i)
  Wait 2
  Move Y=(i)
  Wait 2

AutoPos Y=-55,Z=394,Steps=120
if Help
  ShowMessage "And if I get lost, I really don't mind, 'cause I'll be doing just fine."

# Let Yami jump up
AutoPosObj Yami,33,-65,394,Steps=40,Wait=No
AutoOriObj Yami,0,270,0,Steps=40

# Let the arrows appear
ceny=-72
cenz=394
for i=1 to 100
  if i>1
    DelObj Arrow
  arrowend=radius*i/100
  for j=1 to members
    ShowArrow Start=Point,X=0,Y=(ceny),Z=(cenz),
              End=Point,X=(cos (alpha*j)*arrowend),Y=(ceny),Z=(sin (alpha*j)*arrowend+cenz),
              Radius=3.0,Heads=0,Color=(gmcola(j))
  # Yami jumps away
  if i<=80
    fraction=1.*i/80
    PosObj Yami,X=(fraction*144+33),Y=(fraction*25-65+sin (fraction*180)*30)
    RotateObj Yami,Z=-4.5
  Wait 1

# Move the gyroscope up
gx=0
gy=-86.5
gz=394
for i=1 to 360
  MoveObj !Grass and !Vriend,Y=0.3
  Rotate Y=0.25
  # Don't move the grass
  OriObj Grass,90,0,0
  PosObj Grass,(gx),(gy),(gz)
  Wait 1
HideMessage
  
# Show Gert
LoadPNG Gert
MakeImageObj Gert,Gert,40,56
PosObj Gert,(gx+8),(gy+483+14),(gz)

# Move up
AutoPos Y=-260,Steps=200
RemoveObj Yami
for i=0.0 to 8.4 step 0.1
  Rotate Y=(i)
  Wait 1
Rotate Y=3
AutoRotate Y=8
AutoPos X=0,Y=-350,Z=102,Steps=180
AutoRotate Y=0
Rotate Y=3
for i=8.4 to 0.0 step -0.1
  Rotate Y=(i)
  Wait 1
Wait 60
AutoPos Z=11,Steps=100
Wait 60
ShowMessage "Ouuuuups, sorry Gert!"
Wait 20
AutoPos -5,-373,Steps=50
Wait 120
HideMessage
Wait (Button)

# And down again
AutoPos X=0,Y=-24,Z=354,Steps=160

# Now for every group member
yx=0
yy=-8.4
yz=168
for m=members to 1 step -1
  # Load the image
  LoadPNG (gmlist(m))
  MakeImageObj Info,(gmlist(m)),30,22.5
  AddObj Yami
  PosObj Yami Info,(yx),(yy+200),(yz)
  OriObj Yami,0,0,0
  MoveObj Info,Y=-9.5,-3
  RotateObj Info,X=25
  ShowMessage ((gmlist(m)))
  # Let Yami+Info fall down
  AutoMoveObj Yami Info,Y=-2
  Wait 100
  AutoMoveObj Yami Info,Y=0
  # Let the earth shake
  for j=4 to 1 step -1
    Move Y=(-j)
    Wait 2
    Move Y=(j)
    Wait 2
  Wait 30
  AutoPos Y=-4.5,Z=195,Steps=100
  Wait 100
  Wait (Button)
  
  if gmlist(m)=='Sander' or gmlist(m)=='Elmar'
    # This command will be a NOP in YASARA Movie
    SaveSce backup_(gmlist(m))
    Clear
    UserInput off

    if gmlist(m)=='Sander'
      #
      # Sander's talk about Queen and Dress
      #
      # Load the scene
      LoadSce 1pgb
      # Basic graphics styles
      StickRadius 50
      BallStickRadius 50,50
      ColorBG 336699,eeeeee
      # Move in 1PGB
      Pos1x = PosObj 1
      AutoPosObj 1, -15.132, -0.824, 55.512, Steps=100
      Wait (Button)
      # Make the title
      MakeTextObj Title,Width=400,Height=30
      Font Baikal,Color=White,Depth=2,DepthCol=000000
      Font Height=4%
      PosText 50%,100%,justify=Center
      Print "NMR structure validation"
      Font Height=10%
      PosText 50%,80%,justify=Center
      Print "QUEEN"
      # Make the subtitle
      MakeTextObj Sub,Width=400,Height=30
      Font Baikal,Color=003366,Depth=0,DepthCol=336699
      Font Height=5%
      PosText 50%,10%,justify=Center
      Print "QUantitative Evaluation of Experimental Nmr restraints"
      # Move in the title slide from the top
      PosObj Title,X=-0.57,Y=19,Z=59.55
      AutoPosObj Title,X=-0.57,Y=8.0,Z=59.55,Steps=100,Wait=no
      # Move sub in from bottom
      PosObj Sub,X=-0.57,Y=-19.0,Z=59.55
      AutoPosObj Sub,X=-0.57,Y=-12.0,Z=59.55,Steps=100,Wait=yes
      Wait (Button)
      # Move in restraints in
      Pos4x = PosObj 4
      ShowAtom Element H Obj 4
      AutoPosObj 4, -15.129, -0.824, 55.520, Steps=100
      Wait (Button)
      # Show the image
      LoadPNG queen,transcol=dcdcdc
      ShowImage queen,-525,-205,Width=1024,Height=768,Alpha=0
      MoveImage queen,-525,-205,Width=1024,Height=768,Alpha=100,Steps=6
      Wait (Button)
      # Move the restraints out and fade the image
      MoveImage queen,-525,-205,Width=1024,Height=768,Alpha=0,Steps=60
      AutoPosObj 4,(Pos4x), Steps=100, Wait=No
      # Move the title
      AutoPosObj Title,X=-0.57,Y=19,Z=59.55,Steps=100,Wait=no
      AutoPosObj Sub,X=-0.57,Y=-19.0,Z=59.55,Steps=100
      DelObj Title Sub
      # Make the title
      MakeTextObj Title,Width=400,Height=30
      Font Baikal,Color=White,Depth=2,DepthCol=000000
      Font Height=4%
      PosText 50%,100%,justify=Center
      Print "NMR structure validation"
      Font Height=10%
      PosText 50%,80%,justify=Center
      Print "DRESS"
      # Make the subtitle
      MakeTextObj Sub,Width=400,Height=30
      Font Baikal,Color=003366,Depth=0,DepthCol=336699
      Font Height=5%
      PosText 50%,10%,justify=Center
      Print "Database of REfined Solution nmr Structures"
      # Move in the title slide from the top
      PosObj Title,X=-0.57,Y=19,Z=59.55
      AutoPosObj Title,X=-0.57,Y=8.0,Z=59.55,Steps=100,Wait=no
      # Move sub in from bottom
      PosObj Sub,X=-0.57,Y=-19.0,Z=59.55
      AutoPosObj Sub,X=-0.57,Y=-12.0,Z=59.55,Steps=100,Wait=yes
      Wait (Button)
      # Load quality before
      LoadPNG dressA,transcol=dcdcdc
      ShowImage dressA,-645,-115,Width=1024,Height=768,Alpha=0
      MoveImage dressA,-645,-115,Width=1024,Height=768,Alpha=100,Steps=80
      Wait (Button)
      # Move in the waters in
      Pos3x = PosObj 3
      AutoPosObj 3, -16.605, -1.799, 55.933, Steps=100, Wait=no
      Pos2x = PosObj 2
      AutoPosObj 2, -16.524, -1.570, 55.997, Steps=100, Wait=yes
      Wait (Button)
      # Start the Simulation
      Forcefield YAMBER
      Temperature 270K
      TempCtrl Anneal
      Sim On
      Wait (Button)
      # Load quality after
      LoadPNG dressB,transcol=dcdcdc
      ShowImage dressB,-645,-115,Width=1024,Height=768,Alpha=0
      MoveImage dressB,-645,-115,Width=1024,Height=768,Alpha=100,Steps=80
      Wait (Button)
      Sim Off
      # Recolor the molecule
      ColAtom CA Obj 1,Green
      ColAtom Sidechain Obj 1, Yellow
      # Clean out the scene
      AutoMoveImage dressA,X=-645,Y=-115,Width=1024,Height=768,Alpha=0,Steps=80
      AutoMoveImage dressB,X=-645,Y=-115,Width=1024,Height=768,Alpha=0,Steps=80
      AutoPosObj 3, (Pos3x),Steps=100,Wait=No
      AutoPosObj 1, (Pos1x),Steps=100,Wait=No
      AutoPosObj 2, (Pos2x),Steps=100,Wait=No
      AutoPosObj Title,X=-0.57,Y=19,Z=59.55,Steps=100,Wait=no
      AutoPosObj Sub,X=-0.57,Y=-19.0,Z=59.55,Steps=100

    else
      #
      # Elmar's talk about Homology modeling
      #
      # Load the scene
      StickRadius 70
      BallStickRadius 50,70
      ColorBG 505010,White
      arrowcol='c0c000'
      LoadSce proteinuniv
      SwitchObj 1-11,off

      # Title
      MakeTextObj modeling,Width=500,Height=5
      Font Name=Arial,Height=100%,Color=White,Spacing=2,Depth=4,DepthCol=ff8000
      FontFog off
      PosText 50%,0%,Justify=Center
      Print "Homology Modeling"
      PosObj modeling,Y=21,Z=64
      MakeTextObj sequence,Width=500,Height=5
      Font Height=70%,Color=Black
      PosText 50%,0%,Justify=Center
      Print "MTPAVTTYKLVINGKTLKGETTTKAVDAETA"
      PosObj sequence,X=100,Y=0,Z=64
      MakeTextObj blast,Width=500,Height=5
      PosText 50%,0%,Justify=Center
      Print "BLAST, Fold recognition"
      PosObj blast,Y=-40,Z=64

      # Show Sequence
      if Help
        ShowMessage "When you build a model by homology, you take the sequence of interest..."
      AutoPosObj sequence,X=14,Steps=200
      Wait (Button)

      # Show BLAST
      if Help
        ShowMessage "...and feed it to anything from a simple BLAST to a state-of-the-art fold recognition or threading program."
      ShowArrow Start=Point,0,-3,64,End=Point,0,-19,64,Radius=2.0,Color=c0c000
      AutoPosObj blast,Y=-21,Steps=180,Wait=No
      AutoRotateObj blast,X=2
      Wait 180
      AutoRotateObj blast,X=0
      Wait (Button)

      AutoMoveObj sequence,X=-1
      AutoRotateObj (LastObj),Z=1
      AutoMoveObj (LastObj),Y=-1
      Wait 150
      DelObj sequence (LastObj)

      # Show protein universe
      if Help
        ShowMessage "This program now searches the universe of known structures for a hit..."
      for i=1 to 11
        SwitchObj (i),on
        Wait 10
      Wait (Button)

      # Seek the right template
      if Help
        ShowMessage "using anything from sequence alone to profiles, predicted secondary structure and distance dependent threading functions."
      MakeTextObj O,Width=50,Height=50
      Font Name=Arial,Height=100%,Color=Yellow,Spacing=2,Depth=4,DepthCol=ff8000
      PosText 50%,0%,Justify=Center
      Print "O"

      for i=5 to 1 step -1
        e1,e2,e3=PosObj (i)
        s1,s2,s3=PosObj O
        steps=20
        for j=1 to steps
          f=1.*j/steps
          for k=1 to 3
            p(k)=(1.-f)*s(k)+f*e(k)
          PosObj O,(p1),(p2),(p3)
          ShowArrow Start=Point,0,-19,64,End=Point,(p1),(p2),(p3),Radius=2.0,Color=(arrowcol)
          Wait 1
          DelObj Arrow
      Wait (Button)

      # Let the wrong templates fall away
      if Help
        ShowMessage "Thanks to structural genomics and the exponential growth of the PDB, finding a good template gets increasingly easy.."
      for i=2 to 11
        AutoRotateObj (i),X=1
        AutoMoveObj (i),Y=-1
        Wait 10
      AutoRotateObj blast O,X=1
      AutoMoveObj blast O,Y=-1
      Wait 100
      DelObj 2-11 blast O

      # Zoom in on the right one
      if Help
        ShowMessage "In this example, we want to build a model for protein G, consisting of four beta strands and a helix lying on top."
      pos='X=0,Y=-1.5,Z=56'
      ori='Alpha=-10,Beta=99,Gamma=17'
      AutoPosObj 1,(pos),Steps=100,Wait=No
      AutoOriObj 1,(ori),Steps=100
      Wait (Button)

      # Show the alignment
      LoadPNG alignment
      ShowImage alignment,(512-20),(117-15),40,30,Alpha=0,Priority=1
      AutoMoveImage alignment,0,(-768+236),1024,768,Alpha=80,Steps=200
      Wait 200
      Wait (Button)

      # Loop modeling
      if Help
        ShowMessage "Having chosen the right template, it is time to do some modeling. For example loops with insertions or deletions..."
      Style Ribbon
      for i=01 to 10
        obj=LoadYOb 2igg_l(i)
        SupAtom CA Res 30-61 Obj (obj), CA Res 30-61 Obj 1
        Wait 15
      Wait (Button)
      DelObj 2igg_l??
      if Help
        ShowMessage "...where you sample possible loop conformations and pick the one with the lowest energy."
      Wait (Button)

      # Side-chain modeling
      if Help
        ShowMessage "At least those side-chains that differ between template and target have to be remodeled..."
      StickObj 1
      for i=2 to 61
        ShowAtom SideChain CA Res (i) Obj 1
        Wait 2
      Wait (Button)

      AutoMoveImage alignment,(-1024-512),(-1536+118),4096,3072,Alpha=0,Steps=200
      Wait 100

      # Move to the bottom right
      AutoRotateObj modeling,X=-1
      AutoMoveObj modeling,Y=0.5
      AutoPosObj 1,X=24,Y=-6.6,Z=72,Steps=100
      DelObj modeling

      # The last mile of the protein folding problem
      Clear
      AtomTexture 1
      LoadSCE 2igg
      LoadPDB 2igd
      Style Ribbon,Stick
      PosObj 2igd,X=-60,Y=-6.6,Z=72
      OriObj 2igd,-10,61.3,17

      MakeTextObj lastmile,Width=500,Height=3.8
      Font Name=Arial,Height=100%,Color=White,Spacing=2,Depth=4,DepthCol=ff8000
      FontFog off
      PosText 50%,0%,Justify=Center
      Print "The last mile of the folding problem"
      # Y=28.3
      PosObj lastmile,Y=45,Z=84
      MakeTextObj trgmod,Width=500,Height=2
      Font Height=100%,Color=Black
      PosText 50%,0%,Justify=Center
      Print "Target                      Model"
      PosObj trgmod,Y=-26,Z=40

      if Help
        ShowMessage "So we have got our initial model ready, which is of course just an approximation of the real target structure."
      Wait (Button)

      # Show the target
      AutoPosObj trgmod,Y=-15,Steps=100,Wait=No
      AutoPosObj 2igd,X=-24,Steps=100
      if Help
        ShowMessage "On the left, you can see the real target. You must look precisely to see the differences."
        Wait (Button)
        ShowMessage "If there is a high percentage sequence identity between template and target, the differences can be really small."
      Wait (Button)

      # Show RMSD Arrow
      arrowlen=20.
      for rmsd=2.3 to 0.5 step -0.1
        ShowArrow Point,(arrowlen/2),-6.6,72,Point,(-arrowlen/2+arrowlen*0.85*(rmsd-0.5)/1.8),-6.6,72,Radius=1,Color=(arrowcol)
        MakeTextObj RMSD,Width=40,Height=2
        Font Name=Arial,Height=100%,Color=White,Depth=4,DepthCol=ff8000
        PosText 0%,0%,Justify=Left
        Print 'C'
        Font Name=Symbol
        Print 'a'
        Font Name=Arial
        Print ' RMSD (rmsd) A'
        PosObj RMSD,X=9.2,Y=6.3,Z=64
        Wait 3
        if rmsd==2.3
          if Help
            ShowMessage "Here the initial Calpha RMSD is 2.3 A, and we would like to reduce it all the way down to at least 0.5 A"
            Wait (Button)
            ShowMessage "0.5 A is the border of experimental uncertainty. Below you cannot really tell anymore if the model got better or not."
          Wait (Button)
        if rmsd>0.5
          DelObj RMSD Arrow

      # The last mile
      AutoPosObj lastmile,Y=28.3,Steps=60
      if Help
        ShowMessage "Bridging the gap between the model and the target is a tough problem: the last mile of the protein folding problem."
      Wait (Button)

      # Show the simulation cell
      if Help
        ShowMessage "The most logical way to solve this problem is to follow nature's example: run a molecular dynamics simulation."
      Cell 34.35,43.5,31.7
      PosObj SimCell,X=80,Y=-8.24,Z=71.61
      BallStick
      Wait (Button)
      if Help
        ShowMessage "So we put the model into a simulation box..."
      AutoPosObj SimCell,X=23.7,Steps=100
      Wait (Button)
      ForceField YAMBER2
      Cutoff 5.24
      Boundary Wall
      FillCellWater 1.0
      StickRes HOH
      if Help
        ShowMessage "...fill the cell with water and counter ions..."
      Wait (Button)
      TempCtrl SteepDes
      Sim On
      ColorObj 2igd,Element
      Wait 15
      TempCtrl Rescale
      Temp 25C
      if Help
        ShowMessage "...and run a simulation, hoping that this will improve our model."
      Wait (Button)
      if Help
        ShowMessage "More information can be found in a separate movie about the YAMBER force field."
      Sim Pause
      AutoPos 0,0,27,Steps=200
      Sim Continue
      Wait (Button)

      # Example: CASP5
      Clear
      LoadPNG casp
      LoadPDB t0176
      AutoRotate Y=0.1
      Style Ribbon
      StickRes HOH
      ShowRes HOH
      Pos Z=1100
      AutoPos Z=38,Steps=60
      ShowImage casp,Alpha=0,Priority=1
      MoveImage casp,Alpha=70,Steps=60
      if Help
        ShowMessage "While this shows that YAMBER works in practice, we note that David Baker won CASP with 5 best ab initio predictions ;-)"
      Wait 60
      Wait (Button)
      AutoMoveImage casp,X=512,Y=384,Width=1,Height=1,Alpha=0,Steps=30
      AutoMove Z=30
      Wait 30
      Wait (Button)

    # Restore
    Clear
    LoadSce backup_(gmlist(m)),Settings=Yes
    LoadPNG sky
    LoadPNG grass
    LoadPNG Gert
    LoadPNG (gmlist(m))
    ShowImage sky,0,0,1024,768,Alpha=100,Priority=0
    AutoMoveImage sky,256,256,512,384,Alpha=100,Steps=2000,Cycle=Yes
  HideMessage
  AutoPos Y=-8,Z=234,Steps=100
  AutoPosObj Info,Y=-6.85,Z=50.9,Steps=20,Wait=No
  AutoOriObj Info,Alpha=45.4,Steps=20
  AutoMoveObj Info,Y=-0.3,Z=-0.3
  Wait 10
  AutoRotateObj Info,X=-1
  Wait 80
  DelObj Info
  DelImage (gmlist(m))
  # Gyroscope rotates again
  for i=0.0 to 8.4 step 0.1
    if i==5
      RemoveObj Yami
    Rotate Y=(i)
    Wait 1
  Rotate Y=3
  AutoRotate Y=8
  AutoPos X=0,Y=-60,Z=443,Steps=90
  AutoRotate Y=0
  Rotate Y=(3.-alpha)
  for i=8.4 to 0.0 step -0.1
    Rotate Y=(i)
    Wait 1
  AutoPos X=0,Y=-24,Z=354,Steps=160

# End screen
Pos Y=-600,Z=500
Rotate Z=-20
AutoRotate Y=2
while 1
  for i=1 to 3600
    if i<=1200
      Move Y=0.5
    elif i>2400
      Move Y=-0.5
    x,y=PosObj Vriend
    PosObj Grass,X=0,Y=(y-220),Z=500
    OriObj Grass,90,0,0
    Wait 1
    
